@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Protocol superclass
 ##
-## Copyright (c) 2005-2011,2013-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2011,2013-2014,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -32,6 +32,7 @@ use Net::DRI::Data::Contact;
 use Net::DRI::Data::ContactSet;
 use Net::DRI::Data::Hosts;
 use Net::DRI::Data::StatusList;
+use Net::DRI::Data::LanguageTag;
 
 =pod
 
@@ -61,7 +62,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2011,2013-2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2011,2013-2014,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -79,18 +80,19 @@ sub new
 {
  my ($class,$ctx)=@_;
 
- my $self={	capabilities => {},
-		factories => { 	datetime	=> sub { return DateTime->new(@_); },
-				duration	=> sub { return DateTime::Duration->new(@_); },
-				changes  	=> sub { return Net::DRI::Data::Changes->new(@_); },
-				contact  	=> sub { return Net::DRI::Data::Contact->new(); },
-				contactset 	=> sub { return Net::DRI::Data::ContactSet->new(@_); },
-				hosts		=> sub { return Net::DRI::Data::Hosts->new(@_); },
-				status		=> sub { return Net::DRI::Data::StatusList->new(@_); },
-				},
-		logging   => $ctx->{registry}->logging(),
-		logging_ctx => { registry => $ctx->{registry}->name(), profile => $ctx->{profile}, transport_class => $ctx->{transport_class} },
-	};
+ my $self={ capabilities=> {},
+            factories   => {    datetime    => sub { return DateTime->new(@_); },
+                                duration    => sub { return DateTime::Duration->new(@_); },
+                                changes     => sub { return Net::DRI::Data::Changes->new(@_); },
+                                contact     => sub { return Net::DRI::Data::Contact->new(); },
+                                contactset  => sub { return Net::DRI::Data::ContactSet->new(@_); },
+                                hosts       => sub { return Net::DRI::Data::Hosts->new(@_); },
+                                status      => sub { return Net::DRI::Data::StatusList->new(@_); },
+                                language_tag=> sub { return Net::DRI::Data::LanguageTag->new(@_); },
+                           },
+            logging     => $ctx->{registry}->logging(),
+            logging_ctx => { registry => $ctx->{registry}->name(), profile => $ctx->{profile}, transport_class => $ctx->{transport_class} },
+          };
 
  bless($self,$class);
  $self->message(undef);
@@ -129,7 +131,7 @@ sub create_local_object
  my ($self,$what,@args)=@_;
  return unless defined $self && defined $what;
  my $fn=$self->factories();
- return unless (defined($fn) && ref($fn) && exists($fn->{$what}) && (ref($fn->{$what}) eq 'CODE'));
+ Net::DRI::Exception::err_assert('invalid factory name "'.$what.'"') unless defined $fn && ref $fn eq 'HASH' && exists $fn->{$what} && ref $fn->{$what} eq 'CODE';
  return $fn->{$what}->(@args);
 }
 
