@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Status
 ##
-## Copyright (c) 2005,2007,2008,2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2007,2008,2010,2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2007,2008,2010 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2007,2008,2010,2014 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -98,7 +98,7 @@ sub build_xml
  while(my ($k,$v)=each(%$rd))
  {
   next if (($range eq 'core') xor is_core_status($k));
-  if ($v && ref $v && keys %$v)
+  if ($v && ref $v eq 'HASH' && keys %$v)
   {
    my %tmp=(s => $k);
    $tmp{lang}=$v->{lang} if exists $v->{lang};
