@@ -1,6 +1,6 @@
 ## Domain Registry Interface, NORID (.NO) EPP extensions
 ##
-## Copyright (c) 2008-2010 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+## Copyright (c) 2008-2013 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 ##                    Trond Haugen E<lt>info@norid.noE<gt>
 ##                    All rights reserved.
 ##
@@ -51,7 +51,7 @@ Trond Haugen, E<lt>info@norid.noE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+Copyright (c) 2008-2013 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 Trond Haugen E<lt>info@norid.noE<gt>
 All rights reserved.
 
@@ -70,6 +70,7 @@ sub setup {
     my ($self,$rp)=@_;
     $self->ns({ no_contact => [ 'http://www.norid.no/xsd/no-ext-contact-1.0','no-ext-contact-1.0.xsd' ],
                 no_domain  => [ 'http://www.norid.no/xsd/no-ext-domain-1.0','no-ext-domain-1.0.xsd' ],
+                no_domain_1_1 => [ 'http://www.norid.no/xsd/no-ext-domain-1.1','no-ext-domain-1.1.xsd' ],
                 no_host    => [ 'http://www.norid.no/xsd/no-ext-host-1.0','no-ext-host-1.0.xsd' ],
                 no_result  => [ 'http://www.norid.no/xsd/no-ext-result-1.0','no-ext-result-1.0.xsd' ],
                 no_epp     => [ 'http://www.norid.no/xsd/no-ext-epp-1.0','no-ext-epp-1.0.xsd' ],
@@ -81,6 +82,7 @@ sub setup {
     $self->capabilities('host_update','contact',['set']);
     $self->capabilities('host_update','facets',['set']);
     $self->capabilities('domain_update','facets',['set']);
+    $self->capabilities('domain_update','applicantdataset',['set']);
     $self->factories('contact',sub { return Net::DRI::Data::Contact::NO->new(); });
 
     return;
