@@ -1,6 +1,6 @@
 ## Domain Registry Interface, TCP/SSL Socket Transport
 ##
-## Copyright (c) 2005-2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -23,6 +23,7 @@ use Time::HiRes ();
 use IO::Socket::INET;
 ## At least this version is needed, to have getline()
 use IO::Socket::SSL 0.90;
+use Scalar::Util ();
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
@@ -109,7 +110,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2013,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -367,8 +368,11 @@ sub close_socket
 {
  my ($self)=@_;
  my $t=$self->transport_data();
- $self->sock()->close();
- $self->log_output('notice','transport',{},{phase=>'closing',message=>'Successfully closed socket for '.$t->{remote_uri}});
+ if (defined $self->sock() && Scalar::Util::openhandle($self->sock()))
+ {
+  $self->sock()->close();
+  $self->log_output('notice','transport',{},{phase=>'closing',message=>'Successfully closed socket for '.$t->{remote_uri}});
+ }
  $self->sock(undef);
  return;
 }
